@@ -27,27 +27,21 @@ var corefileTemplate = template.Must(template.New("Corefile").Parse(`{{range .Se
     {{with .ForwardPlugin -}}
     forward .{{range .Upstreams}} {{.}}{{end}}
     {{- end}}
-    errors
 }
 {{end -}}
 .:5353 {
     errors
-    health {
-        lameduck 20s
-    }
-    ready
+    health
     kubernetes {{.ClusterDomain}} in-addr.arpa ip6.arpa {
         pods insecure
         upstream
         fallthrough in-addr.arpa ip6.arpa
     }
-    prometheus :9153
+    prometheus 127.0.0.1:9153
     forward . /etc/resolv.conf {
         policy sequential
     }
-    cache 900 {
-        denial 9984 30
-    }
+    cache 30
     reload
 }
 `))
