@@ -36,31 +36,24 @@ func TestDesiredDNSConfigmap(t *testing.T) {
 	expectedCorefile := `# foo
 foo.com:5353 {
     forward . 1.1.1.1 2.2.2.2:5353
-    errors
 }
 # bar
 bar.com:5353 example.com:5353 {
     forward . 3.3.3.3
-    errors
 }
 .:5353 {
     errors
-    health {
-        lameduck 20s
-    }
-    ready
+    health
     kubernetes cluster.local in-addr.arpa ip6.arpa {
         pods insecure
         upstream
         fallthrough in-addr.arpa ip6.arpa
     }
-    prometheus :9153
+    prometheus 127.0.0.1:9153
     forward . /etc/resolv.conf {
         policy sequential
     }
-    cache 900 {
-        denial 9984 30
-    }
+    cache 30
     reload
 }
 `
